window.Gleam.initSearch([{"doc":"xmljson","title":"xmljson","content":"# xmljson \n\nConverts XML to JSON and vice versa. The JSON schema used is [badgerfish](http://www.sklar.com/badgerfish/). Badgerfish is used because it is mostly lossless, although there are rare cases where information could be lost in the conversion.\n\n[![Package Version](https://img.shields.io/hexpm/v/xmljson)](https://hex.pm/packages/xmljson)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/xmljson/)\n\n```sh\ngleam add xmljson\n```\n```gleam\nimport xmljson\n\npub fn main() {\n  let input = &quot;&lt;alice&gt;bob&lt;/alice&gt;&quot;\n\n  let json = xmljson.to_json(input)\n  // &quot;{ \\&quot;alice\\&quot;: { \\&quot;$\\&quot; : \\&quot;bob\\&quot; } }&quot;\n  xmljson.to_xml_fragment(json)\n  // &quot;&lt;alice&gt;bob&lt;/alice&gt;&quot;\n\n  // Multiple values become a list\n  let input = &quot;&lt;alice&gt;&lt;bob&gt;charlie&lt;/bob&gt;&lt;bob&gt;david&lt;/bob&gt;&lt;/alice&gt;&quot;\n  let json = xmljson.to_json(input)\n  // &quot;{ \\&quot;alice\\&quot;: { \\&quot;bob\\&quot; : [{\\&quot;$\\&quot;: \\&quot;charlie\\&quot; }, {\\&quot;$\\&quot;: \\&quot;david\\&quot; }] } }&quot;\n\n  // Attributes are labelled with an @\n  let input = &quot;&lt;alice charlie=\\&quot;david\\&quot;&gt;bob&lt;/alice&gt;&quot;\n  let json = xmljson.to_json(input)\n  // &quot;{ \\&quot;alice\\&quot;: { \\&quot;$\\&quot; : \\&quot;bob\\&quot;, \\&quot;@charlie\\&quot; : \\&quot;david\\&quot; } }&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/xmljson&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"xmljson/element","title":"DecodeError","content":"pub type DecodeError {\n  DecodeError(message: String)\n}\n\nDecodeError(message: String)\n\n\nSynonyms:\nxmljson/element.DecodeError\nxmljson/element DecodeError","url":"xmljson/element.html#DecodeError"},{"doc":"xmljson/element","title":"Element","content":"pub type Element {\n  Element(\n    name: String,\n    attributes: List(#(String, String)),\n    text: List(String),\n    children: List(Element),\n    namespaces: List(#(String, String)),\n    inherited_namespaces: List(#(String, String)),\n  )\n}\n\nElement(\n  name: String,\n  attributes: List(#(String, String)),\n  text: List(String),\n  children: List(Element),\n  namespaces: List(#(String, String)),\n  inherited_namespaces: List(#(String, String)),\n)\n\n\nSynonyms:\nxmljson/element.Element\nxmljson/element Element","url":"xmljson/element.html#Element"},{"doc":"xmljson/element","title":"from_json","content":"pub fn from_json(\n  json_string: String,\n) -&gt; Result(Element, DecodeError)\n\nSynonyms:\nxmljson/element.from_json\nxmljson/element from_json","url":"xmljson/element.html#from_json"},{"doc":"xmljson/element","title":"from_xml","content":"pub fn from_xml(\n  xml_string: String,\n) -&gt; Result(Element, DecodeError)\n\nSynonyms:\nxmljson/element.from_xml\nxmljson/element from_xml","url":"xmljson/element.html#from_xml"},{"doc":"xmljson/element","title":"inherited_namespaces","content":"pub fn inherited_namespaces(\n  elem: Element,\n  data: List(#(String, String)),\n) -&gt; Element\n\nSynonyms:\nxmljson/element.inherited_namespaces\nxmljson/element inherited_namespaces","url":"xmljson/element.html#inherited_namespaces"},{"doc":"xmljson/element","title":"new","content":"pub fn new(name: String) -&gt; Element\n\nSynonyms:\nxmljson/element.new\nxmljson/element new","url":"xmljson/element.html#new"},{"doc":"xmljson/element","title":"text","content":"pub fn text(elem: Element, data: List(String)) -&gt; Element\n\nSynonyms:\nxmljson/element.text\nxmljson/element text","url":"xmljson/element.html#text"},{"doc":"xmljson/element","title":"to_json","content":"pub fn to_json(elem: Element) -&gt; Json\n\nSynonyms:\nxmljson/element.to_json\nxmljson/element to_json","url":"xmljson/element.html#to_json"},{"doc":"xmljson/element","title":"to_xml","content":"pub fn to_xml(elem: Element) -&gt; String\n\nSynonyms:\nxmljson/element.to_xml\nxmljson/element to_xml","url":"xmljson/element.html#to_xml"},{"doc":"xmljson/element","title":"to_xml_type","content":"pub fn to_xml_type(elem: Element) -&gt; Xml\n\nSynonyms:\nxmljson/element.to_xml_type\nxmljson/element to_xml_type","url":"xmljson/element.html#to_xml_type"},{"doc":"xmljson/element","title":"xmljson/element","content":"","url":"xmljson/element.html"},{"doc":"xmljson","title":"to_json","content":"pub fn to_json(input: String) -&gt; Result(Json, DecodeError)\n Parse an XML string into a JSON object.\nSynonyms:\nxmljson.to_json\nxmljson to_json","url":"xmljson.html#to_json"},{"doc":"xmljson","title":"to_xml","content":"pub fn to_xml(input: String) -&gt; Result(String, DecodeError)\n Parse an JSON object into an xml string.\nSynonyms:\nxmljson.to_xml\nxmljson to_xml","url":"xmljson.html#to_xml"},{"doc":"xmljson","title":"to_xml_fragment","content":"pub fn to_xml_fragment(\n  input: String,\n) -&gt; Result(String, DecodeError)\n Parse an JSON object into an xml fragment.\nSynonyms:\nxmljson.to_xml_fragment\nxmljson to_xml_fragment","url":"xmljson.html#to_xml_fragment"},{"doc":"xmljson","title":"xmljson","content":"","url":"xmljson.html"}]);